@@ -363,6 +363,7 @@ gboolean g_usb_device_claim_interface (GUsbDevice		    *device,
 						  interface);
 		if (rc != LIBUSB_SUCCESS &&
 		    rc != LIBUSB_ERROR_NOT_FOUND && /* No driver attached */
+		    rc != LIBUSB_ERROR_NOT_SUPPORTED && /* win32 */
 		    rc != LIBUSB_ERROR_BUSY /* driver rebound already */)
 			return g_usb_device_libusb_error_to_gerror (device, rc,
 								    error);
@@ -406,6 +407,7 @@ gboolean g_usb_device_release_interface (GUsbDevice		      *device,
 						  interface);
 		if (rc != LIBUSB_SUCCESS &&
 		    rc != LIBUSB_ERROR_NOT_FOUND && /* No driver attached */
+		    rc != LIBUSB_ERROR_NOT_SUPPORTED && /* win32 */
 		    rc != LIBUSB_ERROR_BUSY /* driver rebound already */)
 			return g_usb_device_libusb_error_to_gerror (device, rc,
 								    error);
@@ -1330,7 +1332,7 @@ _g_usb_device_get_device (GUsbDevice	*device)
  * Gets the platform identifier for the device.
  * On Linux, this is the full sysfs path of the device
  *
- * Return value: The platform ID, or %NULL
+ * Return value: The platform ID, e.g. "usb[03:03]"
  *
  * Since: 0.1.1
  **/
